==> tomb_2.11+dfsg.orig.tar.xz: tomb-2.11/AUTHORS.md <==
Cryptsetup was originally written in 2004 by Jana Saout

LUKS extensions are written in 2006 by Clemens Fruhwirth

Tomb is written and maintained since 2007 by [Denis "Jaromil" Roio](https://jaromil.dyne.org)

Tomb includes code and advices by Anathema, Boyska, Hellekin O. Wolf,
Daniel Rodriguez, Parazyd, Alexandre Pujol, AitorATuin, Narrat, Artur
Malimonov and Chris Vogel.

The 'gtomb' GUI based on Zenity is written by Parazyd and Daniel Dias Rodrigues.

The Qt5 desktop tray GUI is written by Gianluca Montecchi.

Python Tomb wrappers are contributed by Reiven and Boyska.

The Docker Tomb wrapper is contributed by Greg Tczap and Jens Rischbieth.

Artwork is contributed by Jordi aka Mon Mort and Logan VanCuren.

Gettext internationalization and Spanish translation is contributed by
Daniel Rodriguez and Francisco Serrador. French translation by
Hellekin and Roy Lockhart, Russian translation by fsLeg and AHOHNMYC,
German translation by Jerry Polfer, Italian translation by
Massimiliano Augello and Swedish translation by PLJ / Kosovoper,
general fixes contributed by Daniel Dias Rodrigues.

Testing, reviews and documentation contributed by Dreamer, Vlax,
Shining the Translucent, Mancausoft, Asbesto Molesto, Nignux, TheJH,
The Grugq, Reiven, GDrooid, Alphazo, Brian May, fsLeg, Narrat, Jerry
Polfer, Jim Turner, Maxime Arthaud, RobertMX, mhogomchungu Mandeep
Bhutani, Emil Lundberg, Joel Montes de Oca, Armin Mesbah, Arusekk,
Stephan Schindel, Asbjørn Apeland, Victor Calvert, bjonnh, SargoDevel,
AitorATuin, Alexis Danizan, Sven Geuer, Greg Tczap, Aaron Janse, Mark
Mykkanen, Alexis Danizan, Steve Litt, James R, Matthieu Crapet, Selene
ToyKeeper, Valentin Heidelberg and...  the Linux Action Show!

Tomb includes an implementation of the "Password-Based Key Derivation
Function v2" based on GCrypt and written by Anthony Thyssen, with
fixes contributed by AitorATuin.

Some of the Tomb developers can be contacted via [GitHub discussions](https://github.com/dyne/Tomb/discussions)
or over Telegram via the [Dyne.org Chat Channel](https://t.me/dyne_chat).

==> tomb_2.12+dfsg.orig.tar.xz: tomb-2.12/AUTHORS.md <==
Cryptsetup was originally written in 2004 by Jana Saout

LUKS extensions are written in 2006 by Clemens Fruhwirth

Tomb is written and maintained since 2007 by [Denis "Jaromil" Roio](https://jaromil.dyne.org)

Tomb includes code and advices by Anathema, Boyska, Hellekin O. Wolf,
Daniel Rodriguez, Parazyd, Alexandre Pujol, AitorATuin, Narrat, Artur
Malimonov and Chris Vogel.

The 'gtomb' GUI based on Zenity is written by Parazyd and Daniel Dias Rodrigues.

The Qt5 desktop tray GUI is written by Gianluca Montecchi.

Python Tomb wrappers are contributed by Reiven and Boyska.

The Docker Tomb wrapper is contributed by Greg Tczap and Jens Rischbieth.

Artwork is contributed by Jordi aka Mon Mort and Logan VanCuren.

Gettext internationalization and Spanish translation is contributed by
Daniel Rodriguez, Francisco Serrador and gallegonovato. French
translation by Hellekin, Roy Lockhart and luzhen, Russian translation
by fsLeg and AHOHNMYC, German translation by Jerry Polfer, Italian
translation by Massimiliano Augello and Gianluca Montecchi, Swedish
translation by PLJ / Kosovoper, Finnish translation by Ricky Tigg,
general fixes contributed by Daniel Dias Rodrigues, Andreas Deininger,
Vladislav Doster and Settoshi Tonami.

Testing, reviews and documentation contributed by Dreamer, Vlax,
Shining the Translucent, Mancausoft, Asbesto Molesto, Nignux, TheJH,
The Grugq, Reiven, GDrooid, Alphazo, Brian May, fsLeg, Narrat, Jerry
Polfer, Jim Turner, Maxime Arthaud, RobertMX, mhogomchungu Mandeep
Bhutani, Emil Lundberg, Joel Montes de Oca, Armin Mesbah, Arusekk,
Stephan Schindel, Asbjørn Apeland, Victor Calvert, bjonnh, SargoDevel,
AitorATuin, Alexis Danizan, Sven Geuer, Greg Tczap, Aaron Janse, Mark
Mykkanen, Alexis Danizan, Steve Litt, James R, Matthieu Crapet, Selene
ToyKeeper, Valentin Heidelberg, ultimatespirit, Llewellyn van der
Merwe, Sven Geuer, Selene ToyKeeper,  and...  the Linux Action Show!

Tomb includes an implementation of the "Password-Based Key Derivation
Function v2" based on GCrypt and written by Anthony Thyssen, with
fixes contributed by AitorATuin.

Some of the Tomb developers can be contacted via [GitHub discussions](https://github.com/dyne/Tomb/discussions)
or over Telegram via the [Dyne.org Chat Channel](https://t.me/dyne_chat).
